Attribute VB_Name = "SrOut2Ws"
'/*======================================================================*/
'/* Source:     SrOut2Ws.bas
'/* Description: SRIM Output conv. to SRIMws.xlsx
'/* Coded:
'/*  Ver.1.11 18.10/15 Ay mod DirSep
'/*      1.10 17.06/27 Ay add Csv2Ws()
'/*      1.00 17.06/16 A.Yoshida(RIKEN) build.
'/*======================================================================*/

Option Explicit
Option Base 0

'       ====================================================
'           Const, WorkArea Variable def.
'       ====================================================

'/*----------------------------------------------------------------------*/
'/* Const.Def.      Work Sheet Structure
'/*----------------------------------------------------------------------*/
Private Const ClmInfo = 3       ' Work sheet information
Private Const ClmEV = 2         ' Energy org.value
Private Const ClmEU = 3         ' Energy org.unit
Private Const ClmE = 4          ' Energy [MeV/u]
Private Const ClmSPe = 5        ' dE/dx Electric [MeV/(mg/cm2)]
Private Const ClmSPn = 6        ' dE/dx Nuclear  [MeV/(mg/cm2)]
Private Const ClmSPt = 7        ' dE/dx Nuclear  [MeV/(mg/cm2)]
Private Const ClmRngV = 8       ' Range  org.value
Private Const ClmRngU = 9       ' Range  org.unit
Private Const ClmRng = 10       ' Range  [um]
Private Const ClmSPfct = 11     ' dE/dx unit conversion factors
Private Const ClmStLngV = 11    ' Straggling Longitudinal org.value
Private Const ClmStLngU = 12    ' Straggling Longitudinal org.unit
Private Const ClmStLng = 13     ' Straggling Longitudinal [um]
Private Const ClmStLtrV = 14    ' Straggling Lateral org.value
Private Const ClmStLtrU = 15    ' Straggling Lateral org.unit
Private Const ClmStLtr = 16     ' Straggling Lateral      [um]
Private Const ClmTgGas = 6      ' Target is Gas ?
Private Const ClmTgAnm = 6      ' Target Atomic Name
Private Const ClmTgAno = 7      ' Target Atomic Number
Private Const ClmTgAP = 8       ' Target Atomic %My
Private Const ClmTgMP = 9       ' Target Mass   %
Private Const ClmCrded = 16     ' Corded info
Private Const RowVer = 3        ' SRIM ver
Private Const RowIonZ = 4       ' Ion Z
Private Const RowIonA = 5       ' Ion A
Private Const RowTgNS = 6       ' Target name Short
Private Const RowTgNL = 7       ' Target name Long
Private Const RowTgDG = 8       ' Target density in [g/cm3]
Private Const RowTgDA = 9       ' Target density in [atoms/cm3]
Private Const RowBrgC = 10      ' Bragg Correction [%]
Private Const RowEmin = 12      ' row # of Emin
Private Const RowEmax = 13      ' row # of Emax
Private Const RowPtbl = 14      ' if Gas, P[Pa]   asuumed in this SRIM data table
Private Const RowTtbl = 15      ' if Gas, T[degC] asuumed in this SRIM data table
Private Const RowSPfct = 6      ' dE/dx unit = 1 .. 8
Private Const RowTgGas = 3      ' Target is Gas ?
Private Const RowTgCmp = 6      ' Target Composition
Private Const RowCrded = 6  ' Corded info

'/*----------------------------------------------------------------------*/
'/* WkArea Def.     Input Text File (Txtϊ) variables
'/*----------------------------------------------------------------------*/
                ' Input file: SRIMoutput.txt
Dim FSO As Object       ' FileSystemObject
Dim FO  As Object       ' FileObject
Dim TSO As Object       ' TextStreamObject

Dim InFn As String      ' Input file name
Dim LnBuf As String     ' one line buffer
Dim SpBuf As Variant    ' split by space char
Dim unE As String, unR As String, unLn As String, unLt As String
Dim fmA As String

'/*----------------------------------------------------------------------*/
'/* WkArea Def.     Input Csv Book (Csvϊ) variables
'/*----------------------------------------------------------------------*/
                ' Input file: eg) SrimOut_Ar40.xlsx
Dim WbI As Workbook                 ' input WorkBook
Dim WsI As Worksheet                ' input WorkSheet
Dim WsINm As String                 ' input WorkSheet name
Dim WsIclmEnd As Long               ' input WorkSheet colum End
Dim WsIrowEnd As Long               ' input WorkSheet Row End
Dim WsIrow As Long                  ' input WorkSheet Row index

'/*----------------------------------------------------------------------*/
'/* WkArea Def.     Output WorkSheet variables
'/*----------------------------------------------------------------------*/
Private Const WSform = "_`ws_"   ' original WS form
Dim WbO As Workbook                 ' output WorkBook = ThisWorkBook
Dim WsO As Worksheet                ' output WorkSheet object
Dim WsONm As String                 ' output WorkSheet name

'       ====================================================
'           Priv. Func / Sub def.
'       ====================================================
'/*----------------------------------------------------------------------*/
'/* (Priv.Sub.)     Open SRIM output text file
'/*----------------------------------------------------------------------*/
Private Sub OpenSrOut(ByVal Fpath As String)
    Set FSO = CreateObject("Scripting.FileSystemObject")
    Set FO = FSO.GetFile(Fpath)
    Set TSO = FO.OpenAsTextStream
End Sub

'/*----------------------------------------------------------------------*/
'/* (Priv.Sub.)     Copy new WS format
'/*----------------------------------------------------------------------*/
Private Function CopyWsForm(ByVal WsONm As String) As Boolean

Dim Ws As Worksheet
Dim i As Integer, msgYN As String

    For Each Ws In WbO.Sheets
        If Ws.Name = WsONm Then
            msgYN = MsgBox("[NV[g[" & WsONm & "] ܂B" _
                & vbCrLf & "㏑܂?", vbYesNo)
            If msgYN = vbNo Then
                CopyWsForm = False
                Exit Function
            End If
            Application.DisplayAlerts = False
            Ws.Delete
            Application.DisplayAlerts = True
            Exit For
        End If
    Next Ws
    
    WbO.Worksheets(WSform).Copy After:=Worksheets(Worksheets.Count)
    ActiveSheet.Name = WsONm
    Set WsO = ThisWorkbook.Worksheets(WsONm)
    CopyWsForm = True
End Function

'/*----------------------------------------------------------------------*/
'/* (Priv.Func.)    Text File Read/Skip N Lines
'/*----------------------------------------------------------------------*/
Private Function SkipLnN(ByVal Nln As Integer) As Boolean

Dim i As Integer
    For i = 1 To Nln
        If (TSO.AtEndOfStream) Then GoTo ExEOF
        LnBuf = TSO.ReadLine
'Debug.Print LnBuf
    Next i
    SkipLnN = True
    Exit Function
ExEOF:
    TSO.Close
    SkipLnN = False
End Function

'/*----------------------------------------------------------------------*/
'/* (Priv.Func.)    Text File Read/Skip Lines until Kwd found
'/*----------------------------------------------------------------------*/
Private Function SkipLnKwd(ByVal Kwd As String) As Boolean

Dim iPos As Integer
    Do Until TSO.AtEndOfStream
        LnBuf = TSO.ReadLine
'Debug.Print LnBuf
        iPos = InStr(LnBuf, Kwd)
        If (iPos > 0) Then GoTo ExFound
    Loop
    TSO.Close
    SkipLnKwd = False
    Exit Function
ExFound:
    SkipLnKwd = True
End Function

'/*----------------------------------------------------------------------*/
'/* (Priv.Func.)    Trim & Replace Spaces
'/*----------------------------------------------------------------------*/
Private Function TrimSpaces(ByVal Buf As String) As String
    Do While InStr(Buf, "  ") > 0
        Buf = Replace(Buf, "  ", " ")
    Loop
    Buf = Trim(Buf)
    TrimSpaces = Buf
End Function

'/*----------------------------------------------------------------------*/
'/* (Priv.Func.)    Trim LnBuf & Split to SpBuf
'/*----------------------------------------------------------------------*/
Private Sub TrimSplit(ByVal SepCh As String)
    LnBuf = TrimSpaces(LnBuf)
    SpBuf = Split(LnBuf, SepCh)
'DmpSpBuf
End Sub

'/*----------------------------------------------------------------------*/
'/* (Priv.Sub.)    SpBuf dump
'/*----------------------------------------------------------------------*/
Private Sub DmpSpBuf()
Dim nSp As Integer, i As Integer
    nSp = UBound(SpBuf)
    For i = 0 To nSp
        Debug.Print nSp; i; "["; SpBuf(i); "]"
    Next
End Sub

'/*----------------------------------------------------------------------*/
'/* (Priv.Func.)    Csv Sheet Skip N Rows
'/*----------------------------------------------------------------------*/
Private Function SkipRowN(ByVal Nrw As Integer) As Boolean

Dim i As Integer
    For i = 1 To Nrw
        WsIrow = WsIrow + 1
        If (WsIrow > WsIrowEnd) Then GoTo Err1
    Next i
    SkipRowN = True
    Exit Function
Err1:
    SkipRowN = False
End Function

'/*----------------------------------------------------------------------*/
'/* (Priv.Func.)    Csv Sheet Find Kwd in current row
'/*----------------------------------------------------------------------*/
Private Function InRowKwd(ByVal Kwd As String) As Integer

Dim iClm As Integer, s As String

    For iClm = 1 To WsIclmEnd
        s = WsI.Cells(WsIrow, iClm).Value
        If (s = Kwd) Then GoTo ExFound
    Next iClm
    InRowKwd = -1
    Exit Function
ExFound:
    InRowKwd = iClm
End Function

'/*----------------------------------------------------------------------*/
'/* (Priv.Func.)    Csv Sheet Skip Rows until Kwd found
'/*----------------------------------------------------------------------*/
Private Function SkipRowKwd(ByVal Kwd As String) As Integer

Dim iClm As Integer
    Do Until WsIrow > WsIrowEnd
        iClm = InRowKwd(Kwd)
        If (iClm >= 0) Then GoTo ExFound
        WsIrow = WsIrow + 1
    Loop
    SkipRowKwd = -1
    Exit Function
ExFound:
    SkipRowKwd = iClm
End Function

'       ====================================================
'           Sub routines for M A I N
'       ====================================================
Private Sub PutE(ByVal iR As Integer, _
    ByVal Eval As String, ByVal Euni As String)

Dim fmc As Long, fm As String, v As Double

    WsO.Cells(iR, ClmEV) = Val(Eval)
    WsO.Cells(iR, ClmEU) = Euni
    
    fmc = RGB(255, 255, 0)
    If (unE <> Euni) Then
        unE = Euni
        fmc = RGB(192, 256, 256)
    End If
    WsO.Cells(iR, ClmEU).Interior.Color = fmc
                
    fm = "=" & Cells(iR, ClmEV).Address(False, False)
    Select Case unE
    Case Is = "eV":     fm = fm & "/1000000/" & fmA
    Case Is = "keV":    fm = fm & "/1000/" & fmA
    Case Is = "MeV":    fm = fm & "/" & fmA
    Case Is = "GeV":    fm = fm & "*1000/" & fmA
    End Select
    WsO.Cells(iR, ClmE) = fm
    
    v = WsO.Cells(iR, ClmE).Value
    Select Case v
    Case Is < 1:        fm = "0.000000"
    Case Is < 100:      fm = "0.00000"
    Case Is < 1000:     fm = "0.0000"
    Case Is < 10000:    fm = "0.000"
    Case Is < 100000:   fm = "0.00"
    Case Else:          fm = "0."
    End Select
    WsO.Cells(iR, ClmE).NumberFormatLocal = fm
End Sub

Private Sub PutSP(ByVal iR As Integer, _
    ByVal SPe As String, ByVal SPn As String)

Dim fm As String
    WsO.Cells(iR, ClmSPe) = Val(SPe)
    WsO.Cells(iR, ClmSPn) = Val(SPn)
    
    fm = "=" & Cells(iR, ClmSPe).Address(False, False)
    fm = fm & "+" & Cells(iR, ClmSPn).Address(False, False)
    WsO.Cells(iR, ClmSPt) = fm
End Sub

Private Sub PutRS(ByVal iR As Integer, _
    ByVal Rval As String, ByVal Runi As String, ByRef unOld As String, _
    ByVal Cval As Integer, ByVal Cuni As Integer, ByVal Cfm As Integer)

Dim fmc As Long, fmU As String, fmV As String, v As Double

    WsO.Cells(iR, Cval) = Val(Rval)
    WsO.Cells(iR, Cuni) = Runi
        
    fmc = RGB(255, 255, 0)
    If (unOld <> Runi) Then
        unOld = Runi
        fmc = RGB(192, 256, 256)
    End If
    WsO.Cells(iR, Cuni).Interior.Color = fmc
        
    fmU = "=" & Cells(iR, Cval).Address(False, False)
    Select Case Runi
    Case Is = "A":
        fmU = fmU & "/1000/10"
        fmV = "0.00000"
    Case Is = "um":
        fmU = fmU
        fmV = "0.000"
    Case Is = "mm":
        fmU = fmU & "*1000"
        fmV = "0.0"
    Case Is = "m":
        fmU = fmU & "*1000000"
        fmV = "0.000E+00"
    Case Is = "km":
        fmU = fmU & "*1000000000"
        fmV = "0.000E+00"
    End Select
    WsO.Cells(iR, Cfm) = fmU
    WsO.Cells(iR, Cfm).NumberFormatLocal = fmV
End Sub

'/*----------------------------------------------------------------------*/
'/*                 M A I N ( 1 )
'/*----------------------------------------------------------------------*/
'/* (Public Sub.) SRIMout conv. to SRIMws
'/*----------------------------------------------------------------------*/
Public Sub SrimOut2Ws(ByVal FpathSRout As String)

Dim iRow As Integer, RowE0 As Integer
Dim s As String, i As Integer
Dim DirSep As String
    
    Set WbO = ThisWorkbook
    OpenSrOut (FpathSRout)
    DirSep = Application.PathSeparator
   
    i = InStrRev(FpathSRout, DirSep)
    s = Mid(FpathSRout, i + 1)
    i = InStr(s, ".")
    If (i > 28) Then i = 28
    If (i < 0) Then i = 1
    WsONm = Left(s, i - 1)
    
    If (CopyWsForm(WsONm) = False) Then GoTo Err3
    WsO.Activate
    Application.ScreenUpdating = True
   
    If (SkipLnKwd("SRIM version") = False) Then GoTo Err1
    TrimSplit (" ")
    WsO.Cells(RowVer, ClmInfo) = SpBuf(3)
   
    If (SkipLnKwd("Disk File") = False) Then GoTo Err1
    i = InStr(LnBuf, "in ")
    SpBuf = Split(Mid(LnBuf, i + 4), ".")
'   DmpSpBuf
    WsO.Cells(RowTgNL, ClmInfo) = SpBuf(0)
    
    If (SkipLnKwd("Ion =") = False) Then GoTo Err1
    i = InStr(LnBuf, "[")
    WsO.Cells(RowIonZ, ClmInfo) = Val(Mid(LnBuf, i + 1))
    i = InStr(LnBuf, "Mass =")
    WsO.Cells(RowIonA, ClmInfo) = Val(Mid(LnBuf, i + 7))
    
    If (SkipLnKwd("Density =") = False) Then GoTo Err1
    TrimSplit (" ")
    WsO.Cells(RowTgDG, ClmInfo) = Val(SpBuf(3))
    WsO.Cells(RowTgDA, ClmInfo) = Val(SpBuf(6))
    
    SkipLnN (1)
    If (InStr(LnBuf, "a GAS") > 0) Then
        WsO.Cells(RowTgGas, ClmTgGas) = "Gas"
    End If
    
    If (SkipLnKwd("Percent") = False) Then GoTo Err1
    SkipLnN (1)
    For iRow = 0 To 7
        SkipLnN (1)
        If (Mid(LnBuf, 3, 1) = "=") Then Exit For
        TrimSplit (" ")
        WsO.Cells(RowTgCmp + iRow, ClmTgAnm) = SpBuf(0)
        WsO.Cells(RowTgCmp + iRow, ClmTgAno) = Val(SpBuf(1))
        WsO.Cells(RowTgCmp + iRow, ClmTgAP) = Val(SpBuf(2))
        WsO.Cells(RowTgCmp + iRow, ClmTgMP) = Val(SpBuf(3))
    Next iRow
    
    If (SkipLnKwd("Bragg") = False) Then GoTo Err1
    TrimSplit (" ")
    WsO.Cells(RowBrgC, ClmInfo) = SpBuf(3)

    If (SkipLnKwd("Stopping Units") = False) Then GoTo Err1
    If (InStr(LnBuf, "MeV / (mg/cm2)") <= 0) Then GoTo Err2
    
    If (SkipLnKwd("Straggling") = False) Then GoTo Err1
    SkipLnN (1)
    
    fmA = WsO.Cells(RowIonA, ClmInfo).Address(True, True)
    unE = "": unR = "": unLn = "": unLt = ""
    RowE0 = WsO.Cells(RowEmin, ClmInfo)
    iRow = 0
    Do
        SkipLnN (1)
        If (InStr(LnBuf, "---") > 0) Then Exit Do
        TrimSplit (" ")
        Call PutE(RowE0 + iRow, SpBuf(0), SpBuf(1))
        Call PutSP(RowE0 + iRow, SpBuf(2), SpBuf(3))
        Call PutRS(RowE0 + iRow, SpBuf(4), SpBuf(5), unR, ClmRngV, ClmRngU, ClmRng)
        Call PutRS(RowE0 + iRow, SpBuf(6), SpBuf(7), unLn, ClmStLngV, ClmStLngU, ClmStLng)
        Call PutRS(RowE0 + iRow, SpBuf(8), SpBuf(9), unLt, ClmStLtrV, ClmStLtrU, ClmStLtr)
        Application.StatusBar = "... Line# =" & Str(RowE0 + iRow)
        iRow = iRow + 1
    Loop
    WsO.Cells(RowEmax, ClmInfo) = RowE0 + iRow - 1
    
    If (SkipLnKwd("Stopping Units") = False) Then GoTo Err1
    SkipLnN (1)
    For iRow = 0 To 7
        SkipLnN (1)
        TrimSplit (" ")
        WsO.Cells(RowSPfct + iRow, ClmSPfct) = Val(SpBuf(0))
    Next iRow
    
    MsgBox "ϊ܂B" & vbCrLf & "V[gKXύXĉB"
    If (WsO.Cells(RowTgGas, ClmTgGas).Value = "Gas") Then
        MsgBox "GasWIłB" & vbCrLf & "Ptbl,Ttbl ̒lYꂸɓ͂ĉB"
    End If
    GoTo Ex1
Err1:
    MsgBox "Err1: ̓t@C[" & InFn & "] rI܂"
    GoTo Err3
Err2:
    MsgBox "Err2: ̓t@C[" & InFn & "] ̒Pʂ [MeV/(mg/cm2)] ł͂܂"
    GoTo Err3
Err3:
    MsgBox "Err3: ϊ𒆎~܂B"
    GoTo Ex1
Ex1:
    Application.StatusBar = False
    TSO.Close
    Set FSO = Nothing
End Sub

'/*----------------------------------------------------------------------*/
'/*                 M A I N ( 2 )
'/*----------------------------------------------------------------------*/
'/* (Public Sub.) SRIMout CSV-Book conv. to SRIMws
'/*----------------------------------------------------------------------*/
Private Sub OneCsvWs2Ws()

Dim iRow As Integer, RowE0 As Integer
Dim s As String, i As Integer
    
    If (CopyWsForm(WsI.Name) = False) Then GoTo Err3
    WsO.Activate
'   WsIclmEnd = WsI.Cells(1, Columns.Count).End(xlToLeft).Column
    WsIclmEnd = 15
    WsIrowEnd = WsI.Cells(Rows.Count, 2).End(xlUp).Row
    WsIrow = 1
    
    i = SkipRowKwd("SRIM"): If (i < 0) Then GoTo Err1
    WsO.Cells(RowVer, ClmInfo) = WsI.Cells(WsIrow, i + 3)
    
    i = SkipRowKwd("Disk"): If (i < 0) Then GoTo Err1
    s = WsI.Cells(WsIrow, i + 7).Value
    i = InStr(s, ".")
    If (i > 0) Then s = Left(s, i - 1)
    WsO.Cells(RowTgNL, ClmInfo) = s
   
    i = SkipRowKwd("Ion"): If (i < 0) Then GoTo Err1
    s = WsI.Cells(WsIrow, i + 3)
    WsO.Cells(RowIonZ, ClmInfo) = Val(Mid(s, Len(s) - 2))
    WsO.Cells(RowIonA, ClmInfo) = WsI.Cells(WsIrow, i + 7)
    
    i = SkipRowKwd("Density"): If (i < 0) Then GoTo Err1
    WsO.Cells(RowTgDG, ClmInfo) = WsI.Cells(WsIrow, i + 2)
    WsO.Cells(RowTgDA, ClmInfo) = WsI.Cells(WsIrow, i + 5)
    
    If (SkipRowN(1) = False) Then GoTo Err1
    If (InRowKwd("GAS") > 0) Then
        WsO.Cells(RowTgGas, ClmTgGas) = "Gas"
    End If
 
    i = SkipRowKwd("Percent"): If (i < 0) Then GoTo Err1
    If (SkipRowN(1) = False) Then GoTo Err1
    For iRow = 0 To 7
        If (SkipRowN(1) = False) Then GoTo Err1
        If (Mid(WsI.Cells(WsIrow, 2), 3, 1) = "=") Then Exit For
        WsO.Cells(RowTgCmp + iRow, ClmTgAnm) = WsI.Cells(WsIrow, 2)
        WsO.Cells(RowTgCmp + iRow, ClmTgAno) = WsI.Cells(WsIrow, 3)
        WsO.Cells(RowTgCmp + iRow, ClmTgAP) = WsI.Cells(WsIrow, 4)
        WsO.Cells(RowTgCmp + iRow, ClmTgMP) = WsI.Cells(WsIrow, 5)
    Next iRow
    
    i = SkipRowKwd("Bragg"): If (i < 0) Then GoTo Err1
    WsO.Cells(RowBrgC, ClmInfo) = WsI.Cells(WsIrow, i + 3)
    
    i = SkipRowKwd("Stopping"): If (i < 0) Then GoTo Err1
    If (WsI.Cells(WsIrow, i + 3).Value <> "MeV") Then GoTo Err2
    If (WsI.Cells(WsIrow, i + 5).Value <> "(mg/cm2)") Then GoTo Err2
    
    i = SkipRowKwd("Straggling"): If (i < 0) Then GoTo Err1
    If (SkipRowN(1) = False) Then GoTo Err1
    
    fmA = WsO.Cells(RowIonA, ClmInfo).Address(True, True)
    unE = "": unR = "": unLn = "": unLt = ""
    RowE0 = WsO.Cells(RowEmin, ClmInfo)
    iRow = 0
    Do
        If (SkipRowN(1) = False) Then GoTo Err1
        If (Left(WsI.Cells(WsIrow, 1), 3) = "---") Then Exit Do
        Call PutE(RowE0 + iRow, WsI.Cells(WsIrow, 2), WsI.Cells(WsIrow, 3))
        Call PutSP(RowE0 + iRow, WsI.Cells(WsIrow, 4), WsI.Cells(WsIrow, 5))
        Call PutRS(RowE0 + iRow, WsI.Cells(WsIrow, 6), WsI.Cells(WsIrow, 7), unR, ClmRngV, ClmRngU, ClmRng)
        Call PutRS(RowE0 + iRow, WsI.Cells(WsIrow, 8), WsI.Cells(WsIrow, 9), unLn, ClmStLngV, ClmStLngU, ClmStLng)
        Call PutRS(RowE0 + iRow, WsI.Cells(WsIrow, 10), WsI.Cells(WsIrow, 11), unLt, ClmStLtrV, ClmStLtrU, ClmStLtr)
        Application.StatusBar = "... Line# =" & Str(RowE0 + iRow)
        iRow = iRow + 1
    Loop
    WsO.Cells(RowEmax, ClmInfo) = RowE0 + iRow - 1
        
    i = SkipRowKwd("Multiply"): If (i < 0) Then GoTo Err1
    If (SkipRowN(1) = False) Then GoTo Err1
    For iRow = 0 To 7
        If (SkipRowN(1) = False) Then GoTo Err1
        WsO.Cells(RowSPfct + iRow, ClmSPfct) = WsI.Cells(WsIrow, 2)
    Next iRow
    
    GoTo Ex1
Err1:
    MsgBox "Err1: ̓t@C[" & InFn & "] rI܂"
    GoTo Err3
Err2:
    MsgBox "Err2: ̓t@C[" & InFn & "] ̒Pʂ [MeV/(mg/cm2)] ł͂܂"
    GoTo Err3
Err3:
    MsgBox "Err3: ϊ𒆎~܂B"
    GoTo Ex1
Ex1:
    Application.StatusBar = False
End Sub

Public Sub SrimCsv2Ws(ByVal FpathSRout As String)

Dim iWsI As Long        ' input WS No.
Dim s As String
Dim WSH As Object       ' Windows Scripting Host(WSH)
    Set WSH = CreateObject("WScript.Shell")
    
    Set WbO = ThisWorkbook
    Set WbI = Workbooks.Open(FpathSRout)
    For iWsI = 1 To WbI.Worksheets.Count
        Set WsI = WbI.Worksheets(iWsI)
        WbO.Activate
        Application.ScreenUpdating = True
        Call OneCsvWs2Ws
        s = WsI.Name & " ̕ϊI܂B̃V[g̕ϊJn܂B"
        WSH.Popup s, 1, "SrimCsv2Ws", vbInformation
    Next
    Set WSH = Nothing
    WbI.Close savechanges:=False
End Sub


'/*----------------------------------------------------------------------*/
'/*                         END of SrOut2Ws
'/*----------------------------------------------------------------------*/
